@@ -7,4 +7,8 @@ import aicmder.commands.utils
 import aicmder.commands.version
 import aicmder.commands.onnx
 import aicmder.commands.init
-import aicmder.commands.pb
\ No newline at end of file
+try:
+    import aicmder.commands.pb
+except:
+    pass
+import aicmder.commands.serve
